Package: antaresEditObject
Type: Package
Title: Edit an 'Antares' Simulation
Version: 1.0.1
Authors@R: c(
    person("Tatiana", "Vargas", email = "tatiana.vargas@rte-france.com", role = c("aut", "cre")),
    person("Frederic", "Breant", role = "ctb"),
    person("Victor", "Perrier", role = c("ctb")),
    person("Baptiste", "Seguinot", role = "ctb"),
    person("Benoit", "Thieurmel", role = "ctb"),
    person("Titouan", "Robert", role = "ctb"),
    person("Jalal-Edine", "Zawam", role = "ctb"),
    person("Etienne", "Sanchez", role = "ctb"),
    person("Janus", "De Bondt", role = "ctb"),
    person("Assil", "Mansouri", role = "ctb"),
    person("Abdallah", "Mahoudi", role = "ctb"),
    person("Clement", "Berthet", role = "ctb"),
    person("Kamel", "Kemiha", role = "ctb"),
    person("Nicolas", "Boitard", role = "ctb"),
    person("RTE", role = "cph"))
Description: Edit an 'Antares' simulation before running it : create new areas, links, thermal
    clusters or binding constraints or edit existing ones. Update 'Antares' general & optimization settings.
    'Antares' is an open source power system generator, more information available here : <https://antares-simulator.org/>.
License: GPL (>= 2)
URL: https://github.com/rte-antares-rpackage/antaresEditObject,
        https://rte-antares-rpackage.github.io/antaresEditObject/
BugReports: https://github.com/rte-antares-rpackage/antaresEditObject/issues
Encoding: UTF-8
RoxygenNote: 7.2.2
Depends: antaresRead (>= 2.4.2)
Imports: assertthat, cli, data.table, httr, grDevices, jsonlite,
        whisker, doParallel, doFuture, memuse, progressr, pbapply,
        parallel, future, plyr, yaml, lifecycle, zip
Suggests: testthat, covr, knitr, rmarkdown, data.tree
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-06-01 09:28:19 UTC; berthetcle
Author: Tatiana Vargas [aut, cre],
  Frederic Breant [ctb],
  Victor Perrier [ctb],
  Baptiste Seguinot [ctb],
  Benoit Thieurmel [ctb],
  Titouan Robert [ctb],
  Jalal-Edine Zawam [ctb],
  Etienne Sanchez [ctb],
  Janus De Bondt [ctb],
  Assil Mansouri [ctb],
  Abdallah Mahoudi [ctb],
  Clement Berthet [ctb],
  Kamel Kemiha [ctb],
  Nicolas Boitard [ctb],
  RTE [cph]
Maintainer: Tatiana Vargas <tatiana.vargas@rte-france.com>
Repository: CRAN
Date/Publication: 2026-06-01 10:20:02 UTC
Built: R 4.6.0; ; 2026-06-01 14:29:21 UTC; unix
