# Generated by roxygen2: do not edit by hand

S3method(print,antares.api.command)
S3method(print,antares.api.commands)
S3method(print,antares.api.logs)
export(activateRES)
export(activateST)
export(adequacyOptions)
export(api_patch)
export(backupStudy)
export(checkRemovedArea)
export(cleanUpOutput)
export(clearScenarioBuilder)
export(computeOtherFromHourlyMulti)
export(computeOtherFromHourlyYear)
export(computeTimeStampFromHourly)
export(convertConfigToAdq)
export(copyOutput)
export(copyStudyWeb)
export(createArea)
export(createBindingConstraint)
export(createBindingConstraintBulk)
export(createCluster)
export(createClusterBulk)
export(createClusterRES)
export(createClusterST)
export(createDSR)
export(createDistrict)
export(createLink)
export(createPSP)
export(createStudy)
export(createStudyAPI)
export(createVariant)
export(create_scb_referential_series_type)
export(deduplicateScenarioBuilder)
export(deleteStudy)
export(dicoGeneralSettings)
export(dicoOptimizationSettings)
export(dicoOutputSettings)
export(editArea)
export(editBindingConstraint)
export(editCluster)
export(editClusterRES)
export(editClusterST)
export(editDSR)
export(editDistrict)
export(editLink)
export(editPSP)
export(filteringOptions)
export(getCapacityDSR)
export(getCapacityPSP)
export(getJobLogs)
export(getJobs)
export(getPlaylist)
export(getVariantCommands)
export(group_values_meta_check)
export(importZipStudyWeb)
export(is_antares_v7)
export(is_antares_v820)
export(list_pollutants_values)
export(mockSimulationAPI)
export(nodalOptimizationOptions)
export(propertiesLinkOptions)
export(readScenarioBuilder)
export(removeArea)
export(removeBindingConstraint)
export(removeCluster)
export(removeClusterRES)
export(removeClusterST)
export(removeDistrict)
export(removeLink)
export(runSimulation)
export(runTsGenerator)
export(scenarioBuilder)
export(searchStudy)
export(setAPImode)
export(setPlaylist)
export(setSolverPath)
export(setThematicTrimming)
export(storage_values_default)
export(updateAdequacySettings)
export(updateGeneralSettings)
export(updateInputSettings)
export(updateOptimizationSettings)
export(updateOutputSettings)
export(updateScenarioBuilder)
export(useVariant)
export(writeEconomicOptions)
export(writeHydroValues)
export(writeIni)
export(writeIniAPI)
export(writeIniFile)
export(writeIniHydro)
export(writeInputTS)
export(writeMiscGen)
export(writeOutputValues)
export(writeSeriesPrepro)
export(writeVariantCommands)
export(writeWaterValues)
import(data.table)
import(doParallel)
import(parallel)
import(pbapply)
import(progressr)
importFrom(antaresRead,api_delete)
importFrom(antaresRead,api_get)
importFrom(antaresRead,api_post)
importFrom(antaresRead,api_put)
importFrom(antaresRead,getAreas)
importFrom(antaresRead,getDistricts)
importFrom(antaresRead,getLinks)
importFrom(antaresRead,readBindingConstraints)
importFrom(antaresRead,readClusterDesc)
importFrom(antaresRead,readClusterSTDesc)
importFrom(antaresRead,readIni)
importFrom(antaresRead,readIniFile)
importFrom(antaresRead,readInputTS)
importFrom(antaresRead,readLayout)
importFrom(antaresRead,setSimulationPath)
importFrom(antaresRead,setSimulationPathAPI)
importFrom(antaresRead,simOptions)
importFrom(assertthat,assert_that)
importFrom(cli,cli_alert_success)
importFrom(data.table,":=")
importFrom(data.table,.SD)
importFrom(data.table,CJ)
importFrom(data.table,as.data.table)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(data.table,melt)
importFrom(data.table,month)
importFrom(data.table,rbindlist)
importFrom(data.table,setcolorder)
importFrom(data.table,setnames)
importFrom(data.table,transpose)
importFrom(data.table,yday)
importFrom(data.table,year)
importFrom(doFuture,registerDoFuture)
importFrom(future,plan)
importFrom(grDevices,col2rgb)
importFrom(httr,PATCH)
importFrom(httr,POST)
importFrom(httr,accept_json)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,content_type_json)
importFrom(httr,status_code)
importFrom(httr,stop_for_status)
importFrom(httr,upload_file)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,unbox)
importFrom(jsonlite,write_json)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(memuse,Sys.meminfo)
importFrom(plyr,ldply)
importFrom(plyr,llply)
importFrom(stats,as.formula)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,URLencode)
importFrom(utils,getFromNamespace)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
importFrom(utils,read.table)
importFrom(utils,tail)
importFrom(utils,tar)
importFrom(utils,unzip)
importFrom(utils,write.table)
importFrom(whisker,whisker.render)
importFrom(yaml,read_yaml)
importFrom(zip,zip)
